@@ -6,10 +6,22 @@ import sys
 import os
 
 
-dll_path = os.path.join(sys.prefix, 'dlls', 'woebin.dll')
+dll_name = None
+
+if sys.platform == "linux" or sys.platform == "linux2":
+    dll_name = 'woebin.so'
+elif sys.platform == "darwin":
+    dll_name = 'woebin.dylib'
+elif sys.platform == "win32":
+    dll_name = 'woebin.dll'
+
+assert dll_name is not None, f"OS not supported: {sys.platform}"
+
+
+dll_path = os.path.join(sys.prefix, 'dlls', dll_name)
 
 if not os.path.exists(dll_path):
-    dll_path = "./target/release/woebin.dll"
+    dll_path = os.path.join('./target/release', dll_name)
 
 
 dll = ctypes.CDLL(dll_path)
